OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Добавлено в избранное",
    "Removed from favorites" : "Удалено из избранного",
    "You added {file} to your favorites" : "Вы добавили «{file}» в избранное",
    "You removed {file} from your favorites" : "Вы удалили «{file}» из избранного",
    "Favorites" : "Избранные",
    "File changes" : "Изменения файлов",
    "Created by {user}" : "Создано пользователем {user}",
    "Changed by {user}" : "Изменено пользователем {user}",
    "Deleted by {user}" : "Удалено пользователем {user}",
    "Restored by {user}" : "Восстановлено пользователем {user}",
    "Renamed by {user}" : "Переименовано пользователем {user}",
    "Moved by {user}" : "Перемещено пользователем {user}",
    "\"remote account\"" : "«пользователь другого сервера»",
    "You created {file}" : "Вы создали «{file}»",
    "You created an encrypted file in {file}" : "Вы создали зашифрованный файл в «{file}»",
    "{user} created {file}" : "{user} создал(а) «{file}»",
    "{user} created an encrypted file in {file}" : "{user} создал(а) зашифрованный файл в «{file}»",
    "{file} was created in a public folder" : "«{file}» создан в общедоступом каталоге",
    "You changed {file}" : "Вы изменили «{file}»",
    "You changed an encrypted file in {file}" : "Вы изменили зашифрованный файл в «{file}»",
    "{user} changed {file}" : "{user} изменил(а) «{file}»",
    "{user} changed an encrypted file in {file}" : "{user} изменил(а) зашифрованный файл в «{file}»",
    "You deleted {file}" : "Вы удалили «{file}»",
    "You deleted an encrypted file in {file}" : "Вы удалили зашифрованный файл в «{file}»",
    "{user} deleted {file}" : "{user} удалил(а) «{file}»",
    "{user} deleted an encrypted file in {file}" : " {user} удалил(а) зашифрованный файл в «{file}»",
    "You restored {file}" : "Вы восстановили «{file}»",
    "{user} restored {file}" : "{user} восстановил(а) «{file}»",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Вы переименовали {oldfile} (скрытый) в {newfile} (скрытый)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Вы переименовали {oldfile} (скрытый) в {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Вы переименовали {oldfile} в {newfile} (скрытый)",
    "You renamed {oldfile} to {newfile}" : "Вы переименовали «{oldfile}» в «{newfile}»",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} переименовал(а) {oldfile} (скрытый) в {newfile} (скрытый)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} переименовал(а) {oldfile} (скрытый) в {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} переименовал(а) {oldfile} в {newfile} (скрытый)",
    "{user} renamed {oldfile} to {newfile}" : "{user} переименовал(а) «{oldfile}» в «{newfile}»",
    "You moved {oldfile} to {newfile}" : "Вы переместили «{oldfile}» в «{newfile}»",
    "{user} moved {oldfile} to {newfile}" : "{user} переместил(а) «{oldfile}» в «{newfile}»",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл добавлен в <strong>избранное</strong> или удалён оттуда",
    "Files" : "Файлы",
    "A file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или каталог",
    "A favorite file or folder has been <strong>changed</strong>" : "<strong>Изменён</strong> файл или папка отмеченные как избранное",
    "Failed to authorize" : "Не удалось авторизовать",
    "Invalid folder path" : "Неверный путь к папке",
    "Folder not found" : "Папка не найдена",
    "The file cannot be found" : "Файл не может быть найден",
    "The destination path does not exist: %1$s" : "Конечный путь не существует: %1$s",
    "You do not have permission to create a file at the specified location" : "У вас нет разрешения на создание файла в указанном месте",
    "The file could not be converted." : "Файл не может быть преобразован.",
    "Could not get relative path to converted file" : "Не удалось получить относительный путь к преобразованному файлу",
    "Favorite files" : "Избранные файлы",
    "No favorites" : "Нет избранного",
    "More favorites" : "Больше избранного",
    "Upload (max. %s)" : "Загрузка (максимум %s)",
    "Accept" : "Принять",
    "Reject" : "Отклонить",
    "Incoming ownership transfer from {user}" : "Запрос передачи владения от пользователя {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Принять владение {path}?\n\nПримечание: процесс переноса может занять до одного часа.",
    "Ownership transfer denied" : "Передача владения отклонена",
    "Your ownership transfer of {path} was denied by {user}." : "Передача владения {path} отклонена {user}.",
    "Ownership transfer failed" : "Не удалось передать владение",
    "Your ownership transfer of {path} to {user} failed." : "Вам не удалось передать владение «{path}» пользователю {user}.",
    "The ownership transfer of {path} from {user} failed." : "Пользователю {user} не удалось передать владение «{path}».",
    "Ownership transfer done" : "Передача владения завершена",
    "Your ownership transfer of {path} to {user} has completed." : "Завершена передача владения «{path}» от вас пользователю {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Завершена передача владения «{path}» от пользователя {user}.",
    "in %s" : "в %s",
    "Transferred from %1$s on %2$s" : "Передано от %1$s %2$s",
    "Files compatibility" : "Совместимость файлов",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Разрешить ограничения на имена файлов для обеспечения возможности их синхронизации со всеми клиентами. По умолчанию разрешены все имена файлов, допустимые в POSIX (например, в Linux или macOS).",
    "Enforce Windows compatibility" : "Обеспечить совместимость с Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Это позволит блокировать имена файлов, недопустимые в системах Windows, например, использующие зарезервированные имена или специальные символы. Однако это не обеспечит совместимость в части чувствительности к регистру.",
    "File Management" : "Управление файлами",
    "Home" : "Главная",
    "Target folder does not exist any more" : "Каталог больше не существует",
    "Reload current directory" : "Обновить текущий каталог",
    "Go to the \"{dir}\" directory" : "Перейти в каталог \"{dir}\"",
    "Current directory path" : "Текущий путь к каталогу",
    "Your have used your space quota and cannot upload files anymore" : "Вы использовали всё доступное вам место и не можете больше загружать файлы",
    "You do not have permission to upload or create files here." : "У вас нет прав загружать или создавать здесь файлы.",
    "Drag and drop files here to upload" : "Перетаскивайте файлы сюда для загрузки",
    "Favorite" : "Добавить в избранное",
    "Back" : "Назад",
    "Toggle selection for file \"{displayName}\"" : "Установить или снять выделение файла «{displayName}»",
    "Toggle selection for folder \"{displayName}\"" : "Установить или снять выделение папки «{displayName}»",
    "File is loading" : "Файл загружается",
    "Folder is loading" : "Папка загружается",
    "Filename" : "Имя файла",
    "Folder name" : "Имя папки",
    "This node is unavailable" : "Этот узел недоступен",
    "Another entry with the same name already exists." : "Другая запись с таким же именем уже существует.",
    "Invalid filename." : "Недопустимое имя файла.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Переименовано «{oldName}» в \"{newName}\"",
    "Rename file" : "Переименовать файл",
    "Pending" : "Ожидается",
    "Unknown date" : "Неизвестная дата",
    "Clear filter" : "Сбросить фильтр",
    "Modified" : "Изменён",
    "Type" : "Тип",
    "Active filters" : "Активные фильтры",
    "Remove filter" : "Удалить фильтр",
    "Total rows summary" : "Количество строк в общем",
    "Toggle selection for all files and folders" : "Установить или снять выделение всех файлов и папок",
    "Name" : "Имя",
    "Size" : "Размер",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" не удалось выполнить некоторые элементы",
    "\"{displayName}\" batch action executed successfully" : "Пакетное действие \"{displayName}\" выполнено успешно",
    "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
    "Actions" : "Действия",
    "(selected)" : "(выбранный)",
    "List of files and folders." : "Список файлов и каталогов.",
    "You have used your space quota and cannot upload files anymore." : "Вы использовали свою квоту свободного места и больше не можете загружать файлы.",
    "Column headers with buttons are sortable." : "Заголовки столбцов с кнопками можно сортировать.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
    "File not found" : "Файл не найден",
    "{count} selected" : "{count} выбрано",
    "{usedQuotaByte} used" : "Использовано {usedQuotaByte}",
    "{used} of {quota} used" : "использовано {used} из {quota}",
    "{relative}% used" : "Использовано {relative}%",
    "Could not refresh storage stats" : "Не удалось обновить данные об использовании хранилища",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище переполнено, файлы больше не могут быть обновлены или синхронизированы.",
    "Storage information" : "Информация о хранении",
    "Storage quota" : "Квота хранилища",
    "New folder" : "Новая папка",
    "Create new folder" : "Создать папку",
    "This name is already in use." : "Это название уже используется.",
    "Create" : "Создать",
    "Fill template fields" : "Заполните поля шаблона",
    "Submitting fields …" : "Отправка полей…",
    "Submit" : "Отправить ответ",
    "Choose a file or folder to transfer" : "Выберите файл или папку для передачи",
    "Transfer" : "Передать",
    "Transfer {path} to {userid}" : "Передать {path} пользователю {userid}",
    "Invalid path selected" : "Указан некорректный путь",
    "Unknown error" : "Неизвестная ошибка",
    "Ownership transfer request sent" : "Запрос на передачу прав владения отправлен",
    "Cannot transfer ownership of a file or folder you do not own" : "Невозможно передать право владения на файл или каталог, которые вам не принадлежат",
    "Transfer ownership of a file or folder" : "Изменение владельца файла или папки",
    "Choose file or folder to transfer" : "Выберите файл или папку для передачи владения",
    "Change" : "Изменить",
    "New owner" : "Новый владелец",
    "Keep {old}" : "Сохранить {old}",
    "Keep without extension" : "Сохранить без расширения",
    "Use {new}" : "Использовать{new}",
    "Remove extension" : "Удалить расширение",
    "Change file extension" : "Изменить расширение файла",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Изменение расширения файла с \"{old}\" на \"{new}\" может сделать файл нечитаемым.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Удаление расширения файла \"{old}\" может сделать файл нечитаемым.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Добавление расширения файла \"{new}\" может сделать его нечитаемым.",
    "Do not show this dialog again." : "Больше не показывать это диалоговое окно.",
    "Select file or folder to link to" : "Выберите файл или папку для создания ссылки",
    "Choose {file}" : "Выберан {file}",
    "Share" : "Поделиться",
    "Shared by link" : "Доступные по ссылке",
    "Shared" : "Опубликованное",
    "Switch to list view" : "Переключение в режим просмотра списка",
    "Switch to grid view" : "Переключиться на режим просмотра сеткой",
    "The file could not be found" : "Файл не найден.",
    "Upload was cancelled by user" : "Загрузка была отменена пользователем",
    "Not enough free space" : "Недостаточно свободного места",
    "Operation is blocked by access control" : "Операция не разрешена модулем контроля доступа",
    "Error during upload: {message}" : "Ошибка при загрузке: {message}",
    "Error during upload, status code {status}" : "Ошибка при передаче на сервер. Сообщение об ошибке: {status}",
    "Unknown error during upload" : "Неизвестная ошибка при загрузке",
    "\"{displayName}\" action executed successfully" : "Действие «{displayName}» выполнено успешно",
    "Loading current folder" : "Загрузка текущей папки",
    "Retry" : "Попробовать снова",
    "No files in here" : "Здесь нет файлов",
    "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
    "Go back" : "Назад",
    "Filter file names …" : "Фильтровать имена файлов…",
    "Views" : "Представления",
    "Files settings" : "Настройки файлов",
    "Your files" : "Ваши файлы",
    "Open in files" : "Открыть в приложении Файлы",
    "File cannot be accessed" : "Не удалось получить доступ к файлу",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не удалось найти файл или у вас отсутствуют права на его просмотр.  Попросите отправителя предоставить вам доступ к этому файлу.",
    "Clipboard is not available" : "Буфер обмена недоступен",
    "WebDAV URL copied to clipboard" : "Ссылка CalDAV скопирована в буфер обмена",
    "Sort favorites first" : "Сначала избранное",
    "Sort folders before files" : "Начинать список с папок",
    "Show hidden files" : "Показывать скрытые файлы",
    "Crop image previews" : "Обрезать пред. просмотр",
    "Enable the grid view" : "Включить режим просмотра сеткой",
    "Enable folder tree" : "Включить дерево папок",
    "Additional settings" : "Дополнительные параметры",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "Ссылка WebDAV",
    "Copy to clipboard" : "Копировать в буфер",
    "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы включили двухфакторную аутентификацию, то нажмите здесь, чтобы создать пароль приложения.",
    "Warnings" : "Предупреждения",
    "Keyboard shortcuts" : "Сочетания клавиш",
    "Speed up your Files experience with these quick shortcuts." : "Ускорьте работу с файлами с помощью сочетаний клавиш.",
    "Open the actions menu for a file" : "Открыть меню действий для файла",
    "Rename a file" : "Переименовать файл",
    "Delete a file" : "Удалить файл",
    "Favorite or remove a file from favorites" : "Добавить или убрать из избранного ",
    "Manage tags for a file" : "Управление тегами файла",
    "Selection" : "Выбор",
    "Select all files" : "Выбрать все файлы",
    "Deselect all files" : "Отменить выбор всех файлов",
    "Select or deselect a file" : "Выберите или отмените выбор файла",
    "Select a range of files" : "Выбрать диапазон файлов",
    "Navigation" : "Навигация",
    "Navigate to the parent folder" : "Перейти к родительской папке",
    "Navigate to the file above" : "Перейти к файлу выше",
    "Navigate to the file below" : "Перейти к файлу ниже",
    "Navigate to the file on the left (in grid mode)" : "Перейдите к файлу слева (в режиме сетки)",
    "Navigate to the file on the right (in grid mode)" : "Перейдите к файлу справа (в режиме сетки)",
    "View" : "Режим просмотра",
    "Toggle the grid view" : "Переключение вида сетки",
    "Open the sidebar for a file" : "Откройте боковую панель для поиска файла",
    "Show those shortcuts" : "Показать ярлыки",
    "You" : "Вы",
    "Shared multiple times with different people" : "Делиться несколько раз с разными людьми",
    "Error while loading the file data" : "Не удалось загрузить данные файла",
    "Owner" : "Владелец",
    "Remove from favorites" : "Удалить из избранных",
    "Add to favorites" : "Добавить в избранное",
    "Tags" : "Метки",
    "Blank" : "Пустой",
    "Unable to create new file from template" : "Не удалось создать файл на основе шаблона",
    "Pick a template for {name}" : "Выбрать шаблон для {name}",
    "Create a new file with the selected template" : "Создать файл на основе шаблона",
    "Creating file" : "Создание файла",
    "Save as {displayName}" : "Сохранить как {displayName}",
    "Save as …" : "Сохранить как…",
    "Converting files …" : "Преобразование файлов…",
    "Failed to convert files: {message}" : "Не удалось преобразовать файлы: {message}",
    "All files failed to be converted" : "Не удалось преобразовать все файлы",
    "One file could not be converted: {message}" : "Один файл не удалось преобразовать: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Файл не удалось преобразовать","%n файлы не могут быть преобразованы","%n файлы не могут быть преобразованы","%n файлы не могут быть преобразованы"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Файл успешно преобразован","%n файлы успешно преобразованы","%n файлы успешно преобразованы","%n файлы успешно преобразованы"],
    "Files successfully converted" : "Файлы успешно конвертированы",
    "Failed to convert files" : "Не удалось преобразовать файлы",
    "Converting file …" : "Преобразование файла…",
    "File successfully converted" : "Файл успешно преобразован",
    "Failed to convert file: {message}" : "Не удалось преобразовать файл: {message}",
    "Failed to convert file" : "Не удалось преобразовать файл",
    "Deletion cancelled" : "Удаление отменено",
    "Leave this share" : "Перестать использовать общий ресурс",
    "Leave these shares" : "Отказаться от доступа к общим ресурсам",
    "Disconnect storage" : "Отсоединить хранилище",
    "Disconnect storages" : "Отключить хранилища",
    "Delete permanently" : "Удалить навсегда",
    "Delete and unshare" : "Удалить и закрыть общий доступ",
    "Delete file" : "Удалить файл",
    "Delete files" : "Удалить файлы",
    "Delete folder" : "Удалить папку",
    "Delete folders" : "Удалить папки",
    "Delete" : "Удалить",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Вы собираетесь безвозвратно удалить {count} элемент","Вы собираетесь безвозвратно удалить {count} элемента","Вы собираетесь безвозвратно удалить {count} элементов","Вы собираетесь безвозвратно удалить {count} элементов"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Подтвердите удаление {count} объекта.","Подтвердите удаление {count} объектов","Подтвердите удаление {count} объектов","Подтвердите удаление {count} объектов"],
    "Confirm deletion" : "Подтвердить удаление",
    "Cancel" : "Отменить",
    "Moving \"{source}\" to \"{destination}\" …" : "Перемещение \"{source}\" в \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Копирование \"{source}\" в \"{destination}\" …",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Папка или файл не могут быть перемещены во вложенную папку или в себя",
    "(copy)" : "(копия)",
    "(copy %n)" : "(копия %n)",
    "Move cancelled" : "Перемещение отменено",
    "A file or folder with that name already exists in this folder" : "В этой папке уже есть файл или папка с этим именем",
    "The files are locked" : "Файлы заблокированы",
    "The file does not exist anymore" : "Файл больше не существует",
    "Choose destination" : "Выберите место назначения",
    "Copy to {target}" : "Скопировать в «{target}»",
    "Copy" : "Копировать",
    "Move to {target}" : "Переместить в «{target}»",
    "Move" : "Переместить",
    "Move or copy operation failed" : "Ошибка перемещение или копирования",
    "Move or copy" : "Переместить или копировать",
    "Cancelled move or copy of \"{filename}\"." : "Отменено перемещение или копирование \"{filename}\".",
    "Cancelled move or copy operation" : "Копирование или перемещение отменено",
    "Open folder {displayName}" : "Открыть папку «{displayName}»",
    "Open in Files" : "Открыть в приложении «Файлы»",
    "Open file locally" : "Открыть файл локально",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Теперь файл должен открыться на вашем устройстве. Если это не произошло, пожалуйста, убедитесь, что у вас установлено настольное приложение.",
    "Retry and close" : "Повторить попытку и закрыть",
    "Open online" : "Открыть онлайн",
    "Failed to redirect to client" : "Ошибка перенаправления в клиент",
    "Open locally" : "Открыть локально",
    "Rename" : "Переименовать",
    "Open details" : "Открыть подробности",
    "View in folder" : "Посмотреть в каталоге",
    "Today" : "Сегодня",
    "Last 7 days" : "Последние 7 дней",
    "Last 30 days" : "Последние 30 дней",
    "This year ({year})" : "Этот год ({year})",
    "Last year ({year})" : "Последний год ({year})",
    "Documents" : "Документы",
    "Spreadsheets" : "Таблицы",
    "Presentations" : "Презентации",
    "PDFs" : "PDFs",
    "Folders" : "Папки",
    "Audio" : "Звук",
    "Photos and images" : "Фотографии и изображения",
    "Videos" : "Видео",
    "New folder creation cancelled" : "Создание новой папки отменено",
    "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
    "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
    "Create templates folder" : "Создать папку шаблонов",
    "Templates" : "Шаблоны",
    "New template folder" : "Новая папка шаблонов",
    "In folder" : "В папке",
    "Search in folder: {folder}" : "Поиск в папке: «{folder}»",
    "One of the dropped files could not be processed" : "Один из перетащенных файлов не может быть обработан",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Папки не будут загружены, так как используемый браузер не поддерживает работу с файловой системой.",
    "No files to upload" : "Не выбрано ни одного файла для передачи на сервер",
    "Unable to create the directory {directory}" : "Не удалось создать папку «{directory}»",
    "Some files could not be uploaded" : "Некоторые файлы не могут быть загружены",
    "Files uploaded successfully" : "Файлы успешно обновлены",
    "No files to process" : "Не ни одного файла для обработки",
    "Some files could not be copied" : "Некоторые файлы не могут быть скопированы",
    "Some files could not be moved" : "Некоторые файлы не могут быть перемещены",
    "Files copied successfully" : "Файлы успешно скопированы",
    "Files moved successfully" : "Файлы успешно перемещены",
    "Conflicts resolution skipped" : "Разрешение конфликтов пропущено",
    "Upload cancelled" : "Передача на сервер отменена",
    "This operation is forbidden" : "Операция запрещена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступен. Проверьте журналы событий или свяжитесь с администратором",
    "Storage is temporarily not available" : "Хранилище временно недоступно",
    "Unexpected error: {error}" : "Неожиданная ошибка: {error}",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки","{folderCount} папок","{folderCount} папки"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файла","{fileCount} файлов","{fileCount} файла"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {folderCount} папка","один файл и {folderCount} папки","один файл и {folderCount} папок","один файл и {folderCount} папки"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл и одна папка","{fileCount} файла и одна папка","{fileCount} файлов и одна папка","{fileCount} файла и одна папка"],
    "{fileCount} files and {folderCount} folders" : "файлов: {fileCount}, папок: {folderCount}",
    "Filename must not be empty." : "Имя файла не должно быть пустым.",
    "\"{char}\" is not allowed inside a filename." : "не допускается внутри имени файла.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "является зарезервированным именем и не допускается для имен файлов.",
    "\"{extension}\" is not an allowed filetype." : "не является разрешенным типом файла.",
    "Filenames must not end with \"{extension}\"." : "Имена файлов не должны заканчиваться на",
    "List of favorite files and folders." : "Список избранных файлов и папок.",
    "No favorites yet" : "В избранное ещё ничего не добавлено ",
    "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
    "All files" : "Все файлы",
    "List of your files and folders." : "Список ваших файлов и каталогов.",
    "All folders" : "Все папки",
    "Personal files" : "Личные файлы",
    "List of your files and folders that are not shared." : "Список ваших неопубликованных файлов и папок.",
    "No personal files found" : "Личные файлы не найдены",
    "Files that are not shared will show up here." : "Файлы, которые не опубликованы, показаны здесь.",
    "Recent" : "Недавно изменённые",
    "List of recently modified files and folders." : "Список недавно измененных файлов и директорий.",
    "No recently modified files" : "Нет недавно измененных файлов",
    "Files and folders you recently modified will show up here." : "Здесь будут показаны недавно изменённые файлы и папки",
    "No entries found in this folder" : "В этом каталоге ничего не найдено",
    "Select all" : "Выбрать всё",
    "Upload too large" : "Файл слишком велик",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере.",
    "File could not be found" : "Невозможно найти файл",
    "Download" : "Скачать",
    "Show list view" : "Просмотр списком",
    "Show grid view" : "Просмотр сеткой",
    "Close" : "Закрыть",
    "Could not create folder \"{dir}\"" : "Невозможно создать каталог «{dir}»",
    "This will stop your current uploads." : "Это действие остановит активные сеансы передачи файлов на сервер. ",
    "Upload cancelled." : "Отправка отменена.",
    "Processing files …" : "Обработка файлов…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно передать «{filename}», так как это либо каталог, либо файл нулевого размера",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, вы передаёте на сервер {size1}, но доступно только {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Целевой каталог «{dir}» более не существует",
    "An unknown error has occurred" : "Произошла неизвестная ошибка",
    "File could not be uploaded" : "Файл не может быть загружен",
    "Uploading …" : "Передача…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Загрузка … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Загрузка этого элемента не поддерживается",
    "Error when assembling chunks, status code {status}" : "Ошибка при сборке чанков, код ошибки {status}",
    "Choose target folder" : "Выбор папки назначения",
    "Set reminder" : "Установить напоминание",
    "Edit locally" : "Редактировать локально",
    "Open" : "Открыть",
    "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
    "Details" : "Подробно",
    "Please select tag(s) to add to the selection" : "Выберите метки для назначения выбранным объектам",
    "Apply tag(s) to selection" : "Назначить метки выбранным объектам",
    "Select directory \"{dirName}\"" : "Выберите каталог \"{dirName}\"",
    "Select file \"{fileName}\"" : "Выберите файл \"{fileName}\"",
    "Unable to determine date" : "Невозможно определить дату",
    "Could not move \"{file}\", target exists" : "Невозможно переместить файл «{file}», он уже существует в каталоге назначения",
    "Could not move \"{file}\"" : "Невозможно переместить файл «{file}»",
    "copy" : "копия",
    "Could not copy \"{file}\", target exists" : "Невозможно скопировать файл «{file}», он уже существует в каталоге назначения",
    "Could not copy \"{file}\"" : "Невозможно скопировать файл «{file}»",
    "Copied {origin} inside {destination}" : "{origin} скопирован в {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} и {nbfiles} других файлов скопированы в {destination}",
    "{newName} already exists" : "«{newName}» уже существует",
    "Could not rename \"{fileName}\", it does not exist any more" : "Невозможно переименовать «{fileName}», файл больше не существует",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя «{targetName}» уже используется в каталоге «{dir}». Выберите другое имя.",
    "Could not rename \"{fileName}\"" : "Невозможно переименовать «{fileName}»",
    "Could not create file \"{file}\"" : "Невозможно создать файл «{file}»",
    "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл «{file}», он уже существует",
    "Could not create folder \"{dir}\" because it already exists" : "Невозможно создать каталог «{dir}», он уже существует",
    "Could not fetch file details \"{file}\"" : "Не удалось получить сведения о файле «{file}»",
    "Error deleting file \"{fileName}\"." : "Ошибка удаления файла «{fileName}».",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нет результатов поиска в других папках для {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Введите более двух символов для поиска в других каталогах",
    "_%n folder_::_%n folders_" : ["%n каталог","%n каталога","%n каталогов","%n каталогов"],
    "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
    "You do not have permission to upload or create files here" : "У вас нет разрешения на загрузку или создание файлов здесь",
    "_Uploading %n file_::_Uploading %n files_" : ["Передача %n файла","Передача %n файлов","Передача %n файлов","Передача %n файлов"],
    "New" : "Новый",
    "New file/folder menu" : "Меню создания файла или папки",
    "Select file range" : "Выбор диапазона файлов",
    "{used}%" : "{used}%",
    "{used} used" : "Использовано {used}",
    "\"{name}\" is an invalid file name." : "«{name}» — недопустимое имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "\"/\" is not allowed inside a file name." : "Символ «/» недопустим в имени файла.",
    "\"{name}\" is not an allowed filetype" : "«{name}» - недопустимый тип файла.",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Хранилище {owner} переполнено, файлы не могут быть обновлены или синхронизированы.",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Папки группы «{mountPoint}» заполнена, файлы не могут быть обновлены или синхронизированы.",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Внешнее хранилище «{mountPoint}» заполнено, файлы не могут быть обновлены или синхронизированы.",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ваше хранилище заполнено, файлы не могут быть обновлены или синхронизированы.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Хранилище пользователя {owner} почти заполнено (использовано {usedSpacePercent} %).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Папка группы «{mountPoint}» почти заполнена (использовано ({usedSpacePercent} %).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Внешнее хранилище «{mountPoint}» почти заполнено (использовано {usedSpacePercent} %).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ваше хранилище почти заполнено (использовано {usedSpacePercent} %).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["соответствуют «{filter}»","соответствуют «{filter}»","соответствуют «{filter}»","соответствует «{filter}»"],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых уже есть доступ к этому файлу или папке. ",
    "Path" : "Путь",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
    "Favorited" : "Избранное",
    "Copy direct link (only works for people who have access to this file/folder)" : "Копировать прямую ссылку (она сработает только для пользователей, у которых уже есть доступ к этому файлу или каталогу)",
    "Upload file" : "Загрузить файл",
    "Not favorited" : "Не избранное",
    "An error occurred while trying to update the tags" : "Во время обновления тегов возникла ошибка",
    "You don't have permission to upload or create files here." : "У вас нет разрешения на загрузку или создание файлов здесь.",
    "Storage informations" : "Сведения о хранилище",
    "Choose file" : "Выберите файл",
    "Go to the previous folder" : "Перейти к предыдущей папке",
    "Open the files app settings" : "Открыть параметры приложения «Файлы»",
    "Unable to change the favourite state of the file" : "Не удалось изменить состояние «избранный» этого файла.",
    "Edit file locally" : "Редактировать файл локально",
    "Edit online" : "Редактировать онлайн",
    "Create new templates folder" : "Создать новую папку шаблонов",
    "List of favorites files and folders." : "Список избранных файлов и каталогов.",
    "Personal Files" : "Личные файлы",
    "Text file" : "Текстовый файл",
    "New text file.txt" : "Новый текстовый файл.txt",
    "Favored" : "Избранные",
    "Favor" : "Услуга",
    "Not favored" : "Не одобрен",
    "Submitting fields…" : "Отправка полей…",
    "Filter filenames…" : "Фильтровать имена файлов…",
    "{count} files could not be converted" : "{count} файлы не могут быть преобразованы",
    "{count} files successfully converted" : "{count} файлы успешно преобразованы"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
